@@ -20,10 +20,10 @@
 
 """Jupyter Notebook Tools for Sphinx.
 
-http://nbsphinx.readthedocs.io/
+https://nbsphinx.readthedocs.io/
 
 """
-__version__ = '0.4.2'
+__version__ = '0.4.3'
 
 import copy
 import json
@@ -76,7 +76,6 @@ DISPLAY_DATA_PRIORITY_LATEX = (
 RST_TEMPLATE = """
 {% extends 'rst.tpl' %}
 
-
 {% macro insert_empty_lines(text) %}
 {%- set before, after = text | get_empty_lines %}
 {%- if before %}
@@ -1563,6 +1562,16 @@ def builder_inited(app):
     for suffix in app.config.nbsphinx_custom_formats:
         app.add_source_suffix(suffix, 'jupyter_notebook')
 
+    if app.config.nbsphinx_requirejs_path:
+        try:
+            # TODO: Add only on pages created from notebooks?
+            app.add_js_file(
+                app.config.nbsphinx_requirejs_path,
+                **app.config.nbsphinx_requirejs_options)
+        except AttributeError:
+            # For Sphinx < 1.8 (nbsphinx_requirejs_options are ignored):
+            app.add_javascript(app.config.nbsphinx_requirejs_path)
+
 
 def html_page_context(app, pagename, templatename, context, doctree):
     """Add CSS string to HTML pages that contain code cells."""
@@ -1645,7 +1654,7 @@ def depart_codearea_latex(self, node):
 
     out.append(
         r'\sphinxsetup{VerbatimBorderColor={named}{nbsphinx-code-border}}')
-    if lines[1].startswith(r'\fvset{'):  # Sphinx >= 1.6.6
+    if lines[1].startswith(r'\fvset{'):  # Sphinx >= 1.6.6 and < 1.8.3
         out.append(lines[1])
         del lines[1]
     assert 'Verbatim' in lines[1]
@@ -1768,6 +1777,16 @@ def setup(app):
     app.add_config_value('nbsphinx_input_prompt', '[%s]:', rebuild='env')
     app.add_config_value('nbsphinx_output_prompt', '[%s]:', rebuild='env')
     app.add_config_value('nbsphinx_custom_formats', {}, rebuild='env')
+    app.add_config_value(
+        'nbsphinx_requirejs_path',
+        'https://cdnjs.cloudflare.com/ajax/libs/require.js/2.3.4/require.min.js',
+        rebuild='html')
+    app.add_config_value(
+        'nbsphinx_requirejs_options',
+        {
+            'integrity': 'sha256-Ae2Vz/4ePdIu6ZyI/5ZGsYnb+m0JlOmKPjt6XZ9JJkA=',
+            'crossorigin': 'anonymous',
+        }, rebuild='html')
 
     app.add_directive('nbinput', NbInput)
     app.add_directive('nboutput', NbOutput)
